@@ -93,13 +93,15 @@ impl<'de> Deserialize<'de> for CommandDataOption {
             String(String),
         }
 
-        fn make_unexpected(unexpected: &ValueEnvelope) -> Unexpected<'_> {
-            match unexpected {
-                ValueEnvelope::Boolean(b) => Unexpected::Bool(*b),
-                ValueEnvelope::Integer(i) => Unexpected::Signed(*i),
-                ValueEnvelope::Number(f) => Unexpected::Float(*f),
-                ValueEnvelope::Id(_id) => Unexpected::Other("ID"),
-                ValueEnvelope::String(s) => Unexpected::Str(s),
+        impl ValueEnvelope {
+            fn as_unexpected(&self) -> Unexpected<'_> {
+                match self {
+                    Self::Boolean(b) => Unexpected::Bool(*b),
+                    Self::Integer(i) => Unexpected::Signed(*i),
+                    Self::Number(f) => Unexpected::Float(*f),
+                    Self::Id(_) => Unexpected::Other("ID"),
+                    Self::String(s) => Unexpected::Str(s),
+                }
             }
         }
 
@@ -190,7 +192,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                             CommandOptionValue::Attachment(id.cast())
                         } else {
                             return Err(DeError::invalid_type(
-                                make_unexpected(&val),
+                                val.as_unexpected(),
                                 &"attachment id",
                             ));
                         }
@@ -201,7 +203,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                         if let ValueEnvelope::Boolean(b) = val {
                             CommandOptionValue::Boolean(b)
                         } else {
-                            return Err(DeError::invalid_type(make_unexpected(&val), &"boolean"));
+                            return Err(DeError::invalid_type(val.as_unexpected(), &"boolean"));
                         }
                     }
                     CommandOptionType::Channel => {
@@ -210,10 +212,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                         if let ValueEnvelope::Id(id) = val {
                             CommandOptionValue::Channel(id.cast())
                         } else {
-                            return Err(DeError::invalid_type(
-                                make_unexpected(&val),
-                                &"channel id",
-                            ));
+                            return Err(DeError::invalid_type(val.as_unexpected(), &"channel id"));
                         }
                     }
                     CommandOptionType::Integer => {
@@ -222,7 +221,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                         if let ValueEnvelope::Integer(i) = val {
                             CommandOptionValue::Integer(i)
                         } else {
-                            return Err(DeError::invalid_type(make_unexpected(&val), &"integer"));
+                            return Err(DeError::invalid_type(val.as_unexpected(), &"integer"));
                         }
                     }
                     CommandOptionType::Mentionable => {
@@ -232,7 +231,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                             CommandOptionValue::Mentionable(id)
                         } else {
                             return Err(DeError::invalid_type(
-                                make_unexpected(&val),
+                                val.as_unexpected(),
                                 &"mentionable id",
                             ));
                         }
@@ -253,7 +252,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                             ValueEnvelope::Number(f) => CommandOptionValue::Number(Number(f)),
                             other => {
                                 return Err(DeError::invalid_type(
-                                    make_unexpected(&other),
+                                    other.as_unexpected(),
                                     &"number",
                                 ));
                             }
@@ -265,7 +264,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                         if let ValueEnvelope::Id(id) = val {
                             CommandOptionValue::Role(id.cast())
                         } else {
-                            return Err(DeError::invalid_type(make_unexpected(&val), &"role id"));
+                            return Err(DeError::invalid_type(val.as_unexpected(), &"role id"));
                         }
                     }
 
@@ -279,7 +278,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                             }
                             other => {
                                 return Err(DeError::invalid_type(
-                                    make_unexpected(&other),
+                                    other.as_unexpected(),
                                     &"string",
                                 ));
                             }
@@ -295,7 +294,7 @@ impl<'de> Deserialize<'de> for CommandDataOption {
                         if let ValueEnvelope::Id(id) = val {
                             CommandOptionValue::User(id.cast())
                         } else {
-                            return Err(DeError::invalid_type(make_unexpected(&val), &"user id"));
+                            return Err(DeError::invalid_type(val.as_unexpected(), &"user id"));
                         }
                     }
                 };
