@@ -2,13 +2,10 @@ mod auto_archive_duration;
 mod listing;
 mod member;
 mod metadata;
-mod news;
-mod private;
-mod public;
 
 pub use self::{
     auto_archive_duration::AutoArchiveDuration, listing::ThreadsListing, member::ThreadMember,
-    metadata::ThreadMetadata, news::NewsThread, private::PrivateThread, public::PublicThread,
+    metadata::ThreadMetadata,
 };
 
 pub(crate) use self::member::ThreadMemberIntermediary;
