@@ -1,7 +1,10 @@
 use crate::{
     gateway::presence::{Presence, PresenceListDeserializer},
     guild::member::{Member, MemberListDeserializer},
-    id::{GuildId, UserId},
+    id::{
+        marker::{GuildMarker, UserMarker},
+        Id,
+    },
 };
 use serde::{
     de::{Deserializer, Error as DeError, IgnoredAny, MapAccess, Visitor},
@@ -13,11 +16,11 @@ use std::fmt::{Formatter, Result as FmtResult};
 pub struct MemberChunk {
     pub chunk_count: u32,
     pub chunk_index: u32,
-    pub guild_id: GuildId,
+    pub guild_id: Id<GuildMarker>,
     pub members: Vec<Member>,
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub nonce: Option<String>,
-    pub not_found: Vec<UserId>,
+    pub not_found: Vec<Id<UserMarker>>,
     #[serde(default)]
     pub presences: Vec<Presence>,
 }
@@ -120,8 +123,7 @@ impl<'de> Visitor<'de> for MemberChunkVisitor {
                     // Since the guild ID may not be deserialized yet we'll use
                     // a temporary placeholder value and update it with the real
                     // guild ID after all the fields have been deserialized.
-                    let deserializer =
-                        MemberListDeserializer::new(GuildId::new(1).expect("non zero"));
+                    let deserializer = MemberListDeserializer::new(Id::new(1));
 
                     members = Some(map.next_value_seed(deserializer)?);
                 }
@@ -144,8 +146,7 @@ impl<'de> Visitor<'de> for MemberChunkVisitor {
                         return Err(DeError::duplicate_field("presences"));
                     }
 
-                    let deserializer =
-                        PresenceListDeserializer::new(GuildId::new(1).expect("non zero"));
+                    let deserializer = PresenceListDeserializer::new(Id::new(1));
 
                     presences = Some(map.next_value_seed(deserializer)?);
                 }
@@ -212,7 +213,8 @@ mod tests {
         datetime::{Timestamp, TimestampParseError},
         gateway::presence::{ClientStatus, Presence, Status, UserOrId},
         guild::Member,
-        id::{GuildId, RoleId, UserId},
+        id::Id,
+        test::image_hash,
         user::{User, UserFlags},
     };
     use std::str::FromStr;
@@ -236,7 +238,7 @@ mod tests {
                 "pending": true,
                 "roles": ["6"],
                 "user": {
-                    "avatar": "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
+                    "avatar": image_hash::AVATAR_INPUT,
                     "discriminator": "0001",
                     "id": "5",
                     "public_flags": 131_072,
@@ -251,7 +253,7 @@ mod tests {
                 "nick": "chunk",
                 "roles": ["6"],
                 "user": {
-                    "avatar": "bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb",
+                    "avatar": image_hash::AVATAR_INPUT,
                     "discriminator": "0001",
                     "id": "6",
                     "username": "test",
@@ -265,7 +267,7 @@ mod tests {
                 "nick": "chunk",
                 "roles": ["6"],
                 "user": {
-                    "avatar": "cccccccccccccccccccccccccccccccc",
+                    "avatar": image_hash::AVATAR_INPUT,
                     "bot": true,
                     "discriminator": "0001",
                     "id": "3",
@@ -283,7 +285,7 @@ mod tests {
                     "7",
                 ],
                 "user": {
-                    "avatar": "dddddddddddddddddddddddddddddddd",
+                    "avatar": image_hash::AVATAR_INPUT,
                     "bot": true,
                     "discriminator": "0001",
                     "id": "2",
@@ -326,26 +328,23 @@ mod tests {
         let expected = MemberChunk {
             chunk_count: 1,
             chunk_index: 0,
-            guild_id: GuildId::new(1).expect("non zero"),
+            guild_id: Id::new(1),
             members: Vec::from([
                 Member {
                     avatar: None,
                     communication_disabled_until: None,
                     deaf: false,
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: false,
                     premium_since: None,
-                    roles: vec![
-                        RoleId::new(6).expect("non zero"),
-                        RoleId::new(7).expect("non zero"),
-                    ],
+                    roles: vec![Id::new(6), Id::new(7)],
                     user: User {
-                        id: UserId::new(2).expect("non zero"),
+                        id: Id::new(2),
                         accent_color: None,
-                        avatar: Some("dddddddddddddddddddddddddddddddd".to_owned()),
+                        avatar: Some(image_hash::AVATAR),
                         banner: None,
                         bot: true,
                         discriminator: 1,
@@ -364,17 +363,17 @@ mod tests {
                     avatar: None,
                     communication_disabled_until: None,
                     deaf: false,
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: false,
                     premium_since: None,
-                    roles: vec![RoleId::new(6).expect("non zero")],
+                    roles: vec![Id::new(6)],
                     user: User {
-                        id: UserId::new(3).expect("non zero"),
+                        id: Id::new(3),
                         accent_color: None,
-                        avatar: Some("cccccccccccccccccccccccccccccccc".to_owned()),
+                        avatar: Some(image_hash::AVATAR),
                         banner: None,
                         bot: true,
                         discriminator: 1,
@@ -393,17 +392,17 @@ mod tests {
                     avatar: None,
                     communication_disabled_until: None,
                     deaf: false,
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: true,
                     premium_since: None,
-                    roles: vec![RoleId::new(6).expect("non zero")],
+                    roles: vec![Id::new(6)],
                     user: User {
-                        id: UserId::new(5).expect("non zero"),
+                        id: Id::new(5),
                         accent_color: None,
-                        avatar: Some("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".to_owned()),
+                        avatar: Some(image_hash::AVATAR),
                         banner: None,
                         bot: false,
                         discriminator: 1,
@@ -422,17 +421,17 @@ mod tests {
                     avatar: None,
                     communication_disabled_until: None,
                     deaf: false,
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: false,
                     premium_since: None,
-                    roles: vec![RoleId::new(6).expect("non zero")],
+                    roles: vec![Id::new(6)],
                     user: User {
-                        id: UserId::new(6).expect("non zero"),
+                        id: Id::new(6),
                         accent_color: None,
-                        avatar: Some("bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb".to_owned()),
+                        avatar: Some(image_hash::AVATAR),
                         banner: None,
                         bot: false,
                         discriminator: 1,
@@ -458,11 +457,9 @@ mod tests {
                         mobile: None,
                         web: Some(Status::Online),
                     },
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     status: Status::Online,
-                    user: UserOrId::UserId {
-                        id: UserId::new(2).expect("non zero"),
-                    },
+                    user: UserOrId::UserId { id: Id::new(2) },
                 },
                 Presence {
                     activities: Vec::new(),
@@ -471,11 +468,9 @@ mod tests {
                         mobile: None,
                         web: Some(Status::Online),
                     },
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     status: Status::Online,
-                    user: UserOrId::UserId {
-                        id: UserId::new(3).expect("non zero"),
-                    },
+                    user: UserOrId::UserId { id: Id::new(3) },
                 },
                 Presence {
                     activities: Vec::new(),
@@ -484,11 +479,9 @@ mod tests {
                         mobile: None,
                         web: None,
                     },
-                    guild_id: GuildId::new(1).expect("non zero"),
+                    guild_id: Id::new(1),
                     status: Status::DoNotDisturb,
-                    user: UserOrId::UserId {
-                        id: UserId::new(5).expect("non zero"),
-                    },
+                    user: UserOrId::UserId { id: Id::new(5) },
                 },
             ]),
         };
