@@ -172,6 +172,7 @@ mod tests {
                 icon: Some(image_hash::ICON),
                 id: Id::new(1),
                 name: "guild name".to_owned(),
+                premium_subscription_count: None,
                 splash: Some(image_hash::SPLASH),
                 vanity_url_code: Some("twilight".to_owned()),
                 verification_level: VerificationLevel::Medium,
@@ -271,7 +272,7 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "InviteGuild",
-                    len: 10,
+                    len: 11,
                 },
                 Token::Str("banner"),
                 Token::Some,
@@ -291,6 +292,8 @@ mod tests {
                 Token::Str("1"),
                 Token::Str("name"),
                 Token::Str("guild name"),
+                Token::Str("premium_subscription_count"),
+                Token::None,
                 Token::Str("splash"),
                 Token::Some,
                 Token::Str(image_hash::SPLASH_INPUT),
